==> huaweicloudsdkworkspaceapp-3.1.69-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/session_printer_options.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SessionPrinterOptions:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'session_printer_customization_policy': 'str'
    }

    attribute_map = {
        'session_printer_customization_policy': 'session_printer_customization_policy'
    }

    def __init__(self, session_printer_customization_policy=None):
        """SessionPrinterOptions

        The model defined in huaweicloud sdk

        :param session_printer_customization_policy: 会话打印机自定义策略。
        :type session_printer_customization_policy: str
        """
        
        

        self._session_printer_customization_policy = None
        self.discriminator = None

        if session_printer_customization_policy is not None:
            self.session_printer_customization_policy = session_printer_customization_policy

    @property
    def session_printer_customization_policy(self):
        """Gets the session_printer_customization_policy of this SessionPrinterOptions.

        会话打印机自定义策略。

        :return: The session_printer_customization_policy of this SessionPrinterOptions.
        :rtype: str
        """
        return self._session_printer_customization_policy

    @session_printer_customization_policy.setter
    def session_printer_customization_policy(self, session_printer_customization_policy):
        """Sets the session_printer_customization_policy of this SessionPrinterOptions.

        会话打印机自定义策略。

        :param session_printer_customization_policy: The session_printer_customization_policy of this SessionPrinterOptions.
        :type session_printer_customization_policy: str
        """
        self._session_printer_customization_policy = session_printer_customization_policy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SessionPrinterOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspaceapp-3.1.156-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/session_printer_options.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class SessionPrinterOptions:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'session_printer_customization_policy': 'str'
    }

    attribute_map = {
        'session_printer_customization_policy': 'session_printer_customization_policy'
    }

    def __init__(self, session_printer_customization_policy=None):
        r"""SessionPrinterOptions

        The model defined in huaweicloud sdk

        :param session_printer_customization_policy: 会话打印机自定义策略。
        :type session_printer_customization_policy: str
        """
        
        

        self._session_printer_customization_policy = None
        self.discriminator = None

        if session_printer_customization_policy is not None:
            self.session_printer_customization_policy = session_printer_customization_policy

    @property
    def session_printer_customization_policy(self):
        r"""Gets the session_printer_customization_policy of this SessionPrinterOptions.

        会话打印机自定义策略。

        :return: The session_printer_customization_policy of this SessionPrinterOptions.
        :rtype: str
        """
        return self._session_printer_customization_policy

    @session_printer_customization_policy.setter
    def session_printer_customization_policy(self, session_printer_customization_policy):
        r"""Sets the session_printer_customization_policy of this SessionPrinterOptions.

        会话打印机自定义策略。

        :param session_printer_customization_policy: The session_printer_customization_policy of this SessionPrinterOptions.
        :type session_printer_customization_policy: str
        """
        self._session_printer_customization_policy = session_printer_customization_policy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SessionPrinterOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
